@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright 2001-2023 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -26,8 +26,8 @@ import (
 	"strings"
 	"testing"
 
+	"git.zabbix.com/ap/plugin-support/zbxerr"
 	"go.mongodb.org/mongo-driver/bson"
-	"golang.zabbix.com/sdk/zbxerr"
 )
 
 func Test_collectionStatsHandler(t *testing.T) {
